<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>DecoderCUEFactory</name>
    <message>
        <location filename="../decodercuefactory.cpp" line="44"/>
        <source>CUE Plugin</source>
        <translation>CUE-Modul</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="47"/>
        <source>CUE Files</source>
        <translation>CUE-Dateien</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="95"/>
        <source>About CUE Audio Plugin</source>
        <translation>Über CUE-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="96"/>
        <source>Qmmp CUE Audio Plugin</source>
        <translation>Qmmp CUE-Audio-Modul</translation>
    </message>
    <message>
        <location filename="../decodercuefactory.cpp" line="97"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>CUE Plugin Settings</source>
        <translation>Einstellungen CUE-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Common settings</source>
        <translation>Allgemeine Einstellungen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Load incorrect cue sheets if possible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>CUE encoding</source>
        <translation>CUE-Kodierung</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Automatic charset detection</source>
        <translation>Automatisches Erkennen des Zeichensatzes</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Language:</source>
        <translation>Sprache:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Default encoding:</source>
        <translation>Standardkodierung:</translation>
    </message>
</context>
</TS>
